# Twitch chests bot

Bot for automatic collection of chests on twitch.

`python -m autochests_bot -h` show all available commands

In debug mode, you can view the area of the screen for processing and the location of the cursor click. These
parameters can be changed by passing arguments when starting the bot.
